==> zio-aws-macie2_2.13-5.17.151.2-sources.jar: zio/aws/macie2/model/BucketCountPolicyAllowsUnencryptedObjectUploads.scala <==
package zio.aws.macie2.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.macie2.model.primitives.__long
import scala.jdk.CollectionConverters._
final case class BucketCountPolicyAllowsUnencryptedObjectUploads(
    allowsUnencryptedObjectUploads: Option[__long] = None,
    deniesUnencryptedObjectUploads: Option[__long] = None,
    unknown: Option[__long] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.macie2.model.BucketCountPolicyAllowsUnencryptedObjectUploads = {
    import BucketCountPolicyAllowsUnencryptedObjectUploads.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.macie2.model.BucketCountPolicyAllowsUnencryptedObjectUploads
      .builder()
      .optionallyWith(
        allowsUnencryptedObjectUploads.map(value => value: java.lang.Long)
      )(_.allowsUnencryptedObjectUploads)
      .optionallyWith(
        deniesUnencryptedObjectUploads.map(value => value: java.lang.Long)
      )(_.deniesUnencryptedObjectUploads)
      .optionallyWith(unknown.map(value => value: java.lang.Long))(_.unknown)
      .build()
  }
  def asReadOnly
      : zio.aws.macie2.model.BucketCountPolicyAllowsUnencryptedObjectUploads.ReadOnly =
    zio.aws.macie2.model.BucketCountPolicyAllowsUnencryptedObjectUploads
      .wrap(buildAwsValue())
}
object BucketCountPolicyAllowsUnencryptedObjectUploads {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.macie2.model.BucketCountPolicyAllowsUnencryptedObjectUploads
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.macie2.model.BucketCountPolicyAllowsUnencryptedObjectUploads =
      zio.aws.macie2.model.BucketCountPolicyAllowsUnencryptedObjectUploads(
        allowsUnencryptedObjectUploads.map(value => value),
        deniesUnencryptedObjectUploads.map(value => value),
        unknown.map(value => value)
      )
    def allowsUnencryptedObjectUploads: Option[__long]
    def deniesUnencryptedObjectUploads: Option[__long]
    def unknown: Option[__long]
    def getAllowsUnencryptedObjectUploads: ZIO[Any, AwsError, __long] =
      AwsError.unwrapOptionField(
        "allowsUnencryptedObjectUploads",
        allowsUnencryptedObjectUploads
      )
    def getDeniesUnencryptedObjectUploads: ZIO[Any, AwsError, __long] =
      AwsError.unwrapOptionField(
        "deniesUnencryptedObjectUploads",
        deniesUnencryptedObjectUploads
      )
    def getUnknown: ZIO[Any, AwsError, __long] =
      AwsError.unwrapOptionField("unknown", unknown)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.macie2.model.BucketCountPolicyAllowsUnencryptedObjectUploads
  ) extends zio.aws.macie2.model.BucketCountPolicyAllowsUnencryptedObjectUploads.ReadOnly {
    override val allowsUnencryptedObjectUploads: Option[__long] = scala
      .Option(impl.allowsUnencryptedObjectUploads())
      .map(value => value: __long)
    override val deniesUnencryptedObjectUploads: Option[__long] = scala
      .Option(impl.deniesUnencryptedObjectUploads())
      .map(value => value: __long)
    override val unknown: Option[__long] =
      scala.Option(impl.unknown()).map(value => value: __long)
  }
  def wrap(
      impl: software.amazon.awssdk.services.macie2.model.BucketCountPolicyAllowsUnencryptedObjectUploads
  ): zio.aws.macie2.model.BucketCountPolicyAllowsUnencryptedObjectUploads.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-macie2_3-5.17.124.3-sources.jar: zio/aws/macie2/model/BucketCountPolicyAllowsUnencryptedObjectUploads.scala <==
package zio.aws.macie2.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.macie2.model.primitives.__long
import scala.jdk.CollectionConverters.*
final case class BucketCountPolicyAllowsUnencryptedObjectUploads(
    allowsUnencryptedObjectUploads: Option[__long] = None,
    deniesUnencryptedObjectUploads: Option[__long] = None,
    unknown: Option[__long] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.macie2.model.BucketCountPolicyAllowsUnencryptedObjectUploads = {
    import BucketCountPolicyAllowsUnencryptedObjectUploads.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.macie2.model.BucketCountPolicyAllowsUnencryptedObjectUploads
      .builder()
      .optionallyWith(
        allowsUnencryptedObjectUploads.map(value =>
          __long.unwrap(value): java.lang.Long
        )
      )(_.allowsUnencryptedObjectUploads)
      .optionallyWith(
        deniesUnencryptedObjectUploads.map(value =>
          __long.unwrap(value): java.lang.Long
        )
      )(_.deniesUnencryptedObjectUploads)
      .optionallyWith(
        unknown.map(value => __long.unwrap(value): java.lang.Long)
      )(_.unknown)
      .build()
  }
  def asReadOnly
      : zio.aws.macie2.model.BucketCountPolicyAllowsUnencryptedObjectUploads.ReadOnly =
    zio.aws.macie2.model.BucketCountPolicyAllowsUnencryptedObjectUploads
      .wrap(buildAwsValue())
}
object BucketCountPolicyAllowsUnencryptedObjectUploads {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.macie2.model.BucketCountPolicyAllowsUnencryptedObjectUploads
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.macie2.model.BucketCountPolicyAllowsUnencryptedObjectUploads =
      zio.aws.macie2.model.BucketCountPolicyAllowsUnencryptedObjectUploads(
        allowsUnencryptedObjectUploads.map(value => value),
        deniesUnencryptedObjectUploads.map(value => value),
        unknown.map(value => value)
      )
    def allowsUnencryptedObjectUploads: Option[__long]
    def deniesUnencryptedObjectUploads: Option[__long]
    def unknown: Option[__long]
    def getAllowsUnencryptedObjectUploads: ZIO[Any, AwsError, __long] =
      AwsError.unwrapOptionField(
        "allowsUnencryptedObjectUploads",
        allowsUnencryptedObjectUploads
      )
    def getDeniesUnencryptedObjectUploads: ZIO[Any, AwsError, __long] =
      AwsError.unwrapOptionField(
        "deniesUnencryptedObjectUploads",
        deniesUnencryptedObjectUploads
      )
    def getUnknown: ZIO[Any, AwsError, __long] =
      AwsError.unwrapOptionField("unknown", unknown)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.macie2.model.BucketCountPolicyAllowsUnencryptedObjectUploads
  ) extends zio.aws.macie2.model.BucketCountPolicyAllowsUnencryptedObjectUploads.ReadOnly {
    override val allowsUnencryptedObjectUploads: Option[__long] = scala
      .Option(impl.allowsUnencryptedObjectUploads())
      .map(value => zio.aws.macie2.model.primitives.__long(value))
    override val deniesUnencryptedObjectUploads: Option[__long] = scala
      .Option(impl.deniesUnencryptedObjectUploads())
      .map(value => zio.aws.macie2.model.primitives.__long(value))
    override val unknown: Option[__long] = scala
      .Option(impl.unknown())
      .map(value => zio.aws.macie2.model.primitives.__long(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.macie2.model.BucketCountPolicyAllowsUnencryptedObjectUploads
  ): zio.aws.macie2.model.BucketCountPolicyAllowsUnencryptedObjectUploads.ReadOnly =
    new Wrapper(impl)
}
